==> manila-7.2.0.tar.gz: manila-7.2.0/manila/policies/share_access_metadata.py <==
# Copyright 2018 Huawei Corporation.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_policy import policy

from manila.policies import base


BASE_POLICY_NAME = 'share_access_metadata:%s'


share_access_rule_metadata_policies = [
    policy.DocumentedRuleDefault(
        name=BASE_POLICY_NAME % 'update',
        check_str=base.RULE_DEFAULT,
        description="Set metadata for a share access rule.",
        operations=[
            {
                'method': 'PUT',
                'path': '/share-access-rules/{share_access_id}/metadata'
            }
        ]),
    policy.DocumentedRuleDefault(
        name=BASE_POLICY_NAME % 'delete',
        check_str=base.RULE_DEFAULT,
        description="Delete metadata for a share access rule.",
        operations=[
            {
                'method': 'DELETE',
                'path': '/share-access-rules/{share_access_id}/metadata/{key}'
            }
        ]),
]


def list_rules():
    return share_access_rule_metadata_policies

==> manila_14.0.0.orig.tar.gz: manila-14.0.0/manila/policies/share_access_metadata.py <==
# Copyright 2018 Huawei Corporation.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_log import versionutils
from oslo_policy import policy

from manila.policies import base


BASE_POLICY_NAME = 'share_access_metadata:%s'

DEPRECATED_REASON = """
The share access metadata API now support system scope and default roles.
"""

deprecated_access_metadata_update = policy.DeprecatedRule(
    name=BASE_POLICY_NAME % 'update',
    check_str=base.RULE_DEFAULT,
    deprecated_reason=DEPRECATED_REASON,
    deprecated_since=versionutils.deprecated.WALLABY
)
deprecated_access_metadata_delete = policy.DeprecatedRule(
    name=BASE_POLICY_NAME % 'delete',
    check_str=base.RULE_DEFAULT,
    deprecated_reason=DEPRECATED_REASON,
    deprecated_since=versionutils.deprecated.WALLABY
)


share_access_rule_metadata_policies = [
    policy.DocumentedRuleDefault(
        name=BASE_POLICY_NAME % 'update',
        check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
        scope_types=['system', 'project'],
        description="Set metadata for a share access rule.",
        operations=[
            {
                'method': 'PUT',
                'path': '/share-access-rules/{share_access_id}/metadata'
            }
        ],
        deprecated_rule=deprecated_access_metadata_update
    ),
    policy.DocumentedRuleDefault(
        name=BASE_POLICY_NAME % 'delete',
        check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
        scope_types=['system', 'project'],
        description="Delete metadata for a share access rule.",
        operations=[
            {
                'method': 'DELETE',
                'path': '/share-access-rules/{share_access_id}/metadata/{key}'
            }
        ],
        deprecated_rule=deprecated_access_metadata_delete
    ),
]


def list_rules():
    return share_access_rule_metadata_policies
